==> cleantalk-8.x-4.7.tar.gz: cleantalk/src/lib/Cleantalk/ApbctDrupal/RemoteCalls.php <==
<?php

namespace Cleantalk\ApbctDrupal;

class RemoteCalls extends \Cleantalk\Common\RemoteCalls {
    /**
     * SFW update
     *
     * @return string
     */
    public function action__sfw_update()
    {
        return \Drupal\cleantalk\CleantalkFuncs::apbct_sfw_update( $this->api_key );
    }

    /**
     * SFW send logs
     *
     * @return string
     */
    public function action__sfw_send_logs()
    {
        return \Drupal\cleantalk\CleantalkFuncs::apbct_sfw_send_logs( $this->api_key );
    }

    public function action__sfw_update__write_base()
    {
        return \Drupal\cleantalk\CleantalkFuncs::apbct_sfw_update( $this->api_key );
    }
    /**
     * Get available remote calls from the storage.
     *
     * @return array
     */
    protected function getAvailableRcActions()
    {
        $remote_calls = \Drupal::state()->get('cleantalk_remote_calls');
        $default_rc = array('close_renew_banner' => array('last_call' => 0, 'cooldown' => self::COOLDOWN), 'sfw_update' => array('last_call' => 0, 'cooldown' => self::COOLDOWN), 'sfw_send_logs' => array('last_call' => 0, 'cooldown' => self::COOLDOWN), 'sfw_update__write_base' => array('last_call' => 0, 'cooldown' => 0));
        if ($remote_calls && !empty($remote_calls)) {
            return empty(array_diff_key($remote_calls, $default_rc)) ? $remote_calls : $default_rc;
        }
        return $default_rc;
    }

    /**
     * Set last call timestamp and save it to the storage.
     *
     * @param array $action
     * @return void
     */
    protected function setLastCall( $action )
    {
        // TODO: Implement setLastCall() method.
        $remote_calls = $this->getAvailableRcActions();
        $remote_calls[$action]['last_call'] = time();
        \Drupal::state()->set('cleantalk_remote_calls',$remote_calls);
    }
}

==> cleantalk-8.x-4.8.tar.gz: cleantalk/src/lib/Cleantalk/ApbctDrupal/RemoteCalls.php <==
<?php

namespace Cleantalk\ApbctDrupal;

class RemoteCalls extends \Cleantalk\Common\RemoteCalls {
    
    /**
     * SFW update
     *
     * @return string
     */
    public function action__sfw_update()
    {
        return \Drupal\cleantalk\CleantalkFuncs::apbct_sfw_update( $this->api_key );
    }

    /**
     * SFW send logs
     *
     * @return string
     */
    public function action__sfw_send_logs()
    {
        return \Drupal\cleantalk\CleantalkFuncs::apbct_sfw_send_logs( $this->api_key );
    }

    public function action__sfw_update__write_base()
    {
        return \Drupal\cleantalk\CleantalkFuncs::apbct_sfw_update( $this->api_key );
    }
    /**
     * Get available remote calls from the storage.
     *
     * @return array
     */
    protected function getAvailableRcActions()
    {
        $remote_calls = \Drupal::state()->get('cleantalk_remote_calls');
        if ($remote_calls && !empty($remote_calls)) {
          return empty(array_diff_key($remote_calls, $this->default_rc)) ? $remote_calls : $this->default_rc;
        }
        return $this->default_rc;
    }

    /**
     * Set last call timestamp and save it to the storage.
     *
     * @param array $action
     * @return void
     */
    protected function setLastCall( $action )
    {
        // TODO: Implement setLastCall() method.
        $remote_calls = $this->getAvailableRcActions();
        $remote_calls[$action]['last_call'] = time();
        \Drupal::state()->set('cleantalk_remote_calls',$remote_calls);
    }
}
